@@ -125,6 +125,7 @@ def create_folders(project_name):
     if not os.path.exists(directories['main']):
         os.mkdir(directories['main'])
 
+    create_main_folders('config', 'main')
     create_main_folders('pipeline', 'main')
     create_main_folders('artifacts', 'pipeline')
     create_main_folders('models', 'artifacts')
@@ -384,7 +385,7 @@ def create_project_config_json():
     with open(os.path.join(__location__, 'cli/config.json'), 'r') as file:
         data = file.read()
         data = data.replace('generatedDirectory', directories['main'])
-        new_file = directories['main'] + '/config.json'
+        new_file = directories['main'] + '/config/config.json'
         if not os.path.exists(new_file):
             f = open(new_file, "w")
             f.write(data)
@@ -413,14 +414,16 @@ def change_to_project_dir():
     os.chdir(directories['main'])
 
 def run_dvc_init():
-    if not os.path.isdir('/.dvc'):
+    dir_path = os.getcwd()
+    if not os.path.isdir(dir_path + '/.dvc'):
         command = 'dvc_init.sh'
         if not isWindows:
             command = './' + command
         subprocess.call(command, shell=True)
 
 def run_git_init():
-    if not os.path.isdir('/.git'):
+    dir_path = os.getcwd()
+    if not os.path.isdir(dir_path + '/.git'):
         command = 'git_init.sh'
         if not isWindows:
             command = './' + command
